@@ -1,13 +1,14 @@
 package Sah::Schema::cpan::pause_id;
 
-our $DATE = '2017-01-08'; # DATE
-our $VERSION = '0.001'; # VERSION
+our $DATE = '2018-04-06'; # DATE
+our $VERSION = '0.002'; # VERSION
+
+ our $schema = ["str",{match=>qr([a-z][a-z0-9]{1,8}),summary=>"PAUSE author ID","x.perl.coerce_rules"=>["str_toupper"]},{}];
 
- our $schema = ["str", {summary=>"PAUSE author ID", match=>qr([a-z][a-z0-9]{1,8})}];
 
 1;
 
-# ABSTRACT:
+# ABSTRACT: PAUSE author ID
 
 __END__
 
@@ -17,11 +18,11 @@ __END__
 
 =head1 NAME
 
-Sah::Schema::cpan::pause_id
+Sah::Schema::cpan::pause_id - PAUSE author ID
 
 =head1 VERSION
 
-This document describes version 0.001 of Sah::Schema::cpan::pause_id (from Perl distribution Sah-Schemas-CPAN), released on 2017-01-08.
+This document describes version 0.002 of Sah::Schema::cpan::pause_id (from Perl distribution Sah-Schemas-CPAN), released on 2018-04-06.
 
 =head1 HOMEPAGE
 
@@ -49,7 +50,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by perlancar@cpan.org.
+This software is copyright (c) 2018, 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
