@@ -1,4 +1,4 @@
-package Sah::Schemas::CPANMeta;
+package Sah::Schemas::CPAN;
 
 1;
 # ABSTRACT: Sah schemas related to CPAN
@@ -11,11 +11,11 @@ __END__
 
 =head1 NAME
 
-Sah::Schemas::CPANMeta - Sah schemas related to CPAN
+Sah::Schemas::CPAN - Sah schemas related to CPAN
 
 =head1 VERSION
 
-This document describes version 0.001 of Sah::Schemas::CPANMeta (from Perl distribution Sah-Schemas-CPAN), released on 2017-01-08.
+This document describes version 0.002 of Sah::Schemas::CPAN (from Perl distribution Sah-Schemas-CPAN), released on 2018-04-06.
 
 =head1 SYNOPSIS
 
@@ -49,7 +49,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by perlancar@cpan.org.
+This software is copyright (c) 2018, 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
